.. _installing:

############
 Installing
############

To install the package, you can use the following command:

.. code:: bash

   python -m pip install anemoi-datasets

If you are interested in creating datasets, you can install the package
with the following command:

.. code:: bash

   pip install anemoi-datasets[create]
